==> ph-ubl21-6.4.0-sources.jar: oasis/names/specification/ubl/schema/xsd/commonextensioncomponents_21/ObjectFactory.java <==

package oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.<p>This class was annotated by ph-jaxb22-plugin -Xph-annotate</p>
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _UBLExtensions_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "UBLExtensions");
    public final static QName _UBLExtension_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "UBLExtension");
    public final static QName _ExtensionAgencyID_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyID");
    public final static QName _ExtensionAgencyName_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyName");
    public final static QName _ExtensionAgencyURI_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyURI");
    public final static QName _ExtensionContent_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionContent");
    public final static QName _ExtensionReason_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionReason");
    public final static QName _ExtensionReasonCode_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionReasonCode");
    public final static QName _ExtensionURI_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionURI");
    public final static QName _ExtensionVersionID_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionVersionID");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link UBLExtensionsType }
     * 
     * @return
     *     The created UBLExtensionsType object and never <code>null</code>.
     */
    @Nonnull
    public UBLExtensionsType createUBLExtensionsType() {
        return new UBLExtensionsType();
    }

    /**
     * Create an instance of {@link UBLExtensionType }
     * 
     * @return
     *     The created UBLExtensionType object and never <code>null</code>.
     */
    @Nonnull
    public UBLExtensionType createUBLExtensionType() {
        return new UBLExtensionType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyIDType }
     * 
     * @return
     *     The created ExtensionAgencyIDType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionAgencyIDType createExtensionAgencyIDType() {
        return new ExtensionAgencyIDType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyNameType }
     * 
     * @return
     *     The created ExtensionAgencyNameType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionAgencyNameType createExtensionAgencyNameType() {
        return new ExtensionAgencyNameType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyURIType }
     * 
     * @return
     *     The created ExtensionAgencyURIType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionAgencyURIType createExtensionAgencyURIType() {
        return new ExtensionAgencyURIType();
    }

    /**
     * Create an instance of {@link ExtensionContentType }
     * 
     * @return
     *     The created ExtensionContentType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionContentType createExtensionContentType() {
        return new ExtensionContentType();
    }

    /**
     * Create an instance of {@link ExtensionReasonType }
     * 
     * @return
     *     The created ExtensionReasonType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionReasonType createExtensionReasonType() {
        return new ExtensionReasonType();
    }

    /**
     * Create an instance of {@link ExtensionReasonCodeType }
     * 
     * @return
     *     The created ExtensionReasonCodeType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionReasonCodeType createExtensionReasonCodeType() {
        return new ExtensionReasonCodeType();
    }

    /**
     * Create an instance of {@link ExtensionURIType }
     * 
     * @return
     *     The created ExtensionURIType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionURIType createExtensionURIType() {
        return new ExtensionURIType();
    }

    /**
     * Create an instance of {@link ExtensionVersionIDType }
     * 
     * @return
     *     The created ExtensionVersionIDType object and never <code>null</code>.
     */
    @Nonnull
    public ExtensionVersionIDType createExtensionVersionIDType() {
        return new ExtensionVersionIDType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UBLExtensionsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link UBLExtensionsType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "UBLExtensions")
    @Nonnull
    public JAXBElement<UBLExtensionsType> createUBLExtensions(
        @Nullable
        final UBLExtensionsType value) {
        return new JAXBElement<UBLExtensionsType>(_UBLExtensions_QNAME, UBLExtensionsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UBLExtensionType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link UBLExtensionType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "UBLExtension")
    @Nonnull
    public JAXBElement<UBLExtensionType> createUBLExtension(
        @Nullable
        final UBLExtensionType value) {
        return new JAXBElement<UBLExtensionType>(_UBLExtension_QNAME, UBLExtensionType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyIDType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyIDType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyID")
    @Nonnull
    public JAXBElement<ExtensionAgencyIDType> createExtensionAgencyID(
        @Nullable
        final ExtensionAgencyIDType value) {
        return new JAXBElement<ExtensionAgencyIDType>(_ExtensionAgencyID_QNAME, ExtensionAgencyIDType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyNameType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyNameType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyName")
    @Nonnull
    public JAXBElement<ExtensionAgencyNameType> createExtensionAgencyName(
        @Nullable
        final ExtensionAgencyNameType value) {
        return new JAXBElement<ExtensionAgencyNameType>(_ExtensionAgencyName_QNAME, ExtensionAgencyNameType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyURIType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyURIType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyURI")
    @Nonnull
    public JAXBElement<ExtensionAgencyURIType> createExtensionAgencyURI(
        @Nullable
        final ExtensionAgencyURIType value) {
        return new JAXBElement<ExtensionAgencyURIType>(_ExtensionAgencyURI_QNAME, ExtensionAgencyURIType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionContentType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionContentType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionContent")
    @Nonnull
    public JAXBElement<ExtensionContentType> createExtensionContent(
        @Nullable
        final ExtensionContentType value) {
        return new JAXBElement<ExtensionContentType>(_ExtensionContent_QNAME, ExtensionContentType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionReasonType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionReasonType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionReason")
    @Nonnull
    public JAXBElement<ExtensionReasonType> createExtensionReason(
        @Nullable
        final ExtensionReasonType value) {
        return new JAXBElement<ExtensionReasonType>(_ExtensionReason_QNAME, ExtensionReasonType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionReasonCodeType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionReasonCodeType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionReasonCode")
    @Nonnull
    public JAXBElement<ExtensionReasonCodeType> createExtensionReasonCode(
        @Nullable
        final ExtensionReasonCodeType value) {
        return new JAXBElement<ExtensionReasonCodeType>(_ExtensionReasonCode_QNAME, ExtensionReasonCodeType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionURIType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionURIType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionURI")
    @Nonnull
    public JAXBElement<ExtensionURIType> createExtensionURI(
        @Nullable
        final ExtensionURIType value) {
        return new JAXBElement<ExtensionURIType>(_ExtensionURI_QNAME, ExtensionURIType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionVersionIDType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionVersionIDType }{@code >} The created JAXBElement and never <code>null</code>.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionVersionID")
    @Nonnull
    public JAXBElement<ExtensionVersionIDType> createExtensionVersionID(
        @Nullable
        final ExtensionVersionIDType value) {
        return new JAXBElement<ExtensionVersionIDType>(_ExtensionVersionID_QNAME, ExtensionVersionIDType.class, null, value);
    }

}

==> ph-ubl21-6.7.0-sources.jar: oasis/names/specification/ubl/schema/xsd/commonextensioncomponents_21/ObjectFactory.java <==

package oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;
import com.helger.commons.annotation.CodingStyleguideUnaware;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.&lt;p&gt;This class was annotated by ph-jaxb22-plugin -Xph-annotate&lt;/p&gt;
 * 
 * 
 */
@XmlRegistry
@CodingStyleguideUnaware
public class ObjectFactory {

    public final static QName _UBLExtensions_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "UBLExtensions");
    public final static QName _UBLExtension_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "UBLExtension");
    public final static QName _ExtensionAgencyID_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyID");
    public final static QName _ExtensionAgencyName_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyName");
    public final static QName _ExtensionAgencyURI_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionAgencyURI");
    public final static QName _ExtensionContent_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionContent");
    public final static QName _ExtensionReason_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionReason");
    public final static QName _ExtensionReasonCode_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionReasonCode");
    public final static QName _ExtensionURI_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionURI");
    public final static QName _ExtensionVersionID_QNAME = new QName("urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", "ExtensionVersionID");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: oasis.names.specification.ubl.schema.xsd.commonextensioncomponents_21
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link UBLExtensionsType }
     * 
     * @return
     *     The created UBLExtensionsType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public UBLExtensionsType createUBLExtensionsType() {
        return new UBLExtensionsType();
    }

    /**
     * Create an instance of {@link UBLExtensionType }
     * 
     * @return
     *     The created UBLExtensionType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public UBLExtensionType createUBLExtensionType() {
        return new UBLExtensionType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyIDType }
     * 
     * @return
     *     The created ExtensionAgencyIDType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionAgencyIDType createExtensionAgencyIDType() {
        return new ExtensionAgencyIDType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyNameType }
     * 
     * @return
     *     The created ExtensionAgencyNameType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionAgencyNameType createExtensionAgencyNameType() {
        return new ExtensionAgencyNameType();
    }

    /**
     * Create an instance of {@link ExtensionAgencyURIType }
     * 
     * @return
     *     The created ExtensionAgencyURIType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionAgencyURIType createExtensionAgencyURIType() {
        return new ExtensionAgencyURIType();
    }

    /**
     * Create an instance of {@link ExtensionContentType }
     * 
     * @return
     *     The created ExtensionContentType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionContentType createExtensionContentType() {
        return new ExtensionContentType();
    }

    /**
     * Create an instance of {@link ExtensionReasonType }
     * 
     * @return
     *     The created ExtensionReasonType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionReasonType createExtensionReasonType() {
        return new ExtensionReasonType();
    }

    /**
     * Create an instance of {@link ExtensionReasonCodeType }
     * 
     * @return
     *     The created ExtensionReasonCodeType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionReasonCodeType createExtensionReasonCodeType() {
        return new ExtensionReasonCodeType();
    }

    /**
     * Create an instance of {@link ExtensionURIType }
     * 
     * @return
     *     The created ExtensionURIType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionURIType createExtensionURIType() {
        return new ExtensionURIType();
    }

    /**
     * Create an instance of {@link ExtensionVersionIDType }
     * 
     * @return
     *     The created ExtensionVersionIDType object and never &lt;code&gt;null&lt;/code&gt;.
     */
    @Nonnull
    public ExtensionVersionIDType createExtensionVersionIDType() {
        return new ExtensionVersionIDType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UBLExtensionsType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link UBLExtensionsType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "UBLExtensions")
    @Nonnull
    public JAXBElement<UBLExtensionsType> createUBLExtensions(
        @Nullable
        final UBLExtensionsType value) {
        return new JAXBElement<UBLExtensionsType>(_UBLExtensions_QNAME, UBLExtensionsType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UBLExtensionType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link UBLExtensionType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "UBLExtension")
    @Nonnull
    public JAXBElement<UBLExtensionType> createUBLExtension(
        @Nullable
        final UBLExtensionType value) {
        return new JAXBElement<UBLExtensionType>(_UBLExtension_QNAME, UBLExtensionType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyIDType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyIDType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyID")
    @Nonnull
    public JAXBElement<ExtensionAgencyIDType> createExtensionAgencyID(
        @Nullable
        final ExtensionAgencyIDType value) {
        return new JAXBElement<ExtensionAgencyIDType>(_ExtensionAgencyID_QNAME, ExtensionAgencyIDType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyNameType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyNameType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyName")
    @Nonnull
    public JAXBElement<ExtensionAgencyNameType> createExtensionAgencyName(
        @Nullable
        final ExtensionAgencyNameType value) {
        return new JAXBElement<ExtensionAgencyNameType>(_ExtensionAgencyName_QNAME, ExtensionAgencyNameType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyURIType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionAgencyURIType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionAgencyURI")
    @Nonnull
    public JAXBElement<ExtensionAgencyURIType> createExtensionAgencyURI(
        @Nullable
        final ExtensionAgencyURIType value) {
        return new JAXBElement<ExtensionAgencyURIType>(_ExtensionAgencyURI_QNAME, ExtensionAgencyURIType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionContentType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionContentType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionContent")
    @Nonnull
    public JAXBElement<ExtensionContentType> createExtensionContent(
        @Nullable
        final ExtensionContentType value) {
        return new JAXBElement<ExtensionContentType>(_ExtensionContent_QNAME, ExtensionContentType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionReasonType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionReasonType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionReason")
    @Nonnull
    public JAXBElement<ExtensionReasonType> createExtensionReason(
        @Nullable
        final ExtensionReasonType value) {
        return new JAXBElement<ExtensionReasonType>(_ExtensionReason_QNAME, ExtensionReasonType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionReasonCodeType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionReasonCodeType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionReasonCode")
    @Nonnull
    public JAXBElement<ExtensionReasonCodeType> createExtensionReasonCode(
        @Nullable
        final ExtensionReasonCodeType value) {
        return new JAXBElement<ExtensionReasonCodeType>(_ExtensionReasonCode_QNAME, ExtensionReasonCodeType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionURIType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionURIType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionURI")
    @Nonnull
    public JAXBElement<ExtensionURIType> createExtensionURI(
        @Nullable
        final ExtensionURIType value) {
        return new JAXBElement<ExtensionURIType>(_ExtensionURI_QNAME, ExtensionURIType.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link ExtensionVersionIDType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link ExtensionVersionIDType }{@code >} The created JAXBElement and never &lt;code&gt;null&lt;/code&gt;.
     */
    @XmlElementDecl(namespace = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2", name = "ExtensionVersionID")
    @Nonnull
    public JAXBElement<ExtensionVersionIDType> createExtensionVersionID(
        @Nullable
        final ExtensionVersionIDType value) {
        return new JAXBElement<ExtensionVersionIDType>(_ExtensionVersionID_QNAME, ExtensionVersionIDType.class, null, value);
    }

}
